# mcgibs NASA Global Imagery Browse Services


MCP Server for [NASA GIBS](https://www.earthdata.nasa.gov/engage/open-data-services-software/earthdata-developer-portal/gibs-api)

[Detailed API Docs](https://nasa-gibs.github.io/gibs-api-docs/]

NASA's Global Imagery Browse Services (GIBS) system provides visualizations of NASA Earth Science observations through standardized web services. These services deliver global, full-resolution visualizations of satellite data to users in a highly responsive manner, enabling visual discovery of scientific phenomena, supporting timely decision-making for natural hazards, educating the next generation of scientists, and making imagery of the planet more accessible to the media and public. Browse all of these visualizations through our Worldview application.

GIBS visualization layers are based on satellite data that has been transformed into pre-generated visualizations stored as a tile pyramid (see figure below). GIBS coordinates with NASA data centers and science teams to regularly ingest visualizations based on remotely sensed satellite data. By processing, storing, and serving these visualizations as pre-generated tiles, GIBS can enable highly responsive access to its visualizations. See here for more background on how tiled web maps work.
